
# Type: disrupts


describes a relationship where one entity degrades or interferes with the structure, function, or occurrence of another.

URI: [biolink:disrupts](https://w3id.org/biolink/vocab/disrupts)


## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>0..*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [affects](affects.md)

## Children


## Used by

 * [NamedThing](NamedThing.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | SEMMEDDB:DISRUPTS |
| **In Subsets:** | | translator_minimal |

